<?php
/**
 * Clikki functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Clikki
 */

if ( ! function_exists( 'clikki_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function clikki_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Clikki, use a find and replace
	 * to change 'clikki' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'clikki', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_editor_style();
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'clikki-small-thumbnail',  100, 100, true );
	add_image_size( 'clikki-featured-thumbnail',  600, 400, true );
	add_image_size( 'clikki-widget-post-thumb',  100, 100, true );
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 400,
		'flex-height' => true,
		'flex-width'  => true,
		'header-text' => array( 'site-title', 'site-description' ),
	) );
	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'clikki' ),
		'secondary' => __('Top Menu', 'clikki')
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'clikki_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}
endif;
add_action( 'after_setup_theme', 'clikki_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function clikki_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'clikki_content_width', 640 );
}
add_action( 'after_setup_theme', 'clikki_content_width', 0 );

$args = array(
	'width'         => 1170,
	'height'        => 200,
);
add_theme_support( 'custom-header', $args );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function clikki_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'clikki' ),
		'id'            => 'clikki-sidebar-1',
		'description'   => __( 'Main Sidebar', 'clikki' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Header Widget', 'clikki' ),
		'id' => 'clikki-header-widget',
		'description'   => __( 'Your header widget', 'clikki' ),
		'before_widget' => '<div id="header-widget" class="header-widget">',
		'after_widget' => "</div>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Footer One', 'clikki' ),
		'id' => 'clikki-footer-one-widget',
		'description'   => __( 'Footer first column widget', 'clikki' ),
		'before_widget' => '<div id="footer-one" class="widget footer-widget">',
		'after_widget' => "</div>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Footer Two', 'clikki' ),
		'id' => 'clikki-footer-two-widget',
		'description'   => __( 'Footer second column widget', 'clikki' ),
		'before_widget' => '<div id="footer-two" class="widget footer-widget">',
		'after_widget' => "</div>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
	register_sidebar( array(
		'name' => __( 'Footer Three', 'clikki' ),
		'id' => 'clikki-footer-three-widget',
		'description'   => __( 'Footer third column widget', 'clikki' ),
		'before_widget' => '<div id="footer-three" class="widget footer-widget">',
		'after_widget' => "</div>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
	
}
add_action( 'widgets_init', 'clikki_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function clikki_scripts() {
	
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() .'/assets/css/bootstrap.css' );
	wp_enqueue_style( 'flexslider', get_template_directory_uri() .'/assets/css/flexslider.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() .'/assets/font-awesome/css/font-awesome.min.css' );
	wp_enqueue_style('clikki-google-fonts', '//fonts.googleapis.com/css?family=Lato:400,300,700,900|Oswald:400,700,300');
	wp_enqueue_style( 'clikki-ie', get_stylesheet_directory_uri() . "/assets/css/ie.css", array()  );
	wp_style_add_data( 'clikki-ie', 'conditional', 'IE' );
	wp_enqueue_style( 'clikki-style', get_stylesheet_uri() );
	
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') );
	wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/js/jquery.flexslider.js', array('jquery') );
	wp_enqueue_script( 'clikki-custom-js', get_template_directory_uri() . '/js/custom.js', array('jquery-masonry', 'imagesloaded') );
	wp_enqueue_script( 'clikki-ie-responsive-js', get_template_directory_uri() . '/js/ie-responsive.min.js', array() );
	wp_script_add_data( 'clikki-ie-responsive-js', 'conditional', 'lt IE 9' );
	wp_enqueue_script( 'clikki-ie-shiv', get_template_directory_uri() . "/js/html5shiv.min.js");
	wp_script_add_data( 'clikki-ie-shiv', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'clikki-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	wp_enqueue_script( 'clikki-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
	
	$clikki_carousel_speed = 6000;
	if ( get_theme_mod( 'clikki_featured_carousel_speed_setting' ) ) {
		$clikki_carousel_speed = get_theme_mod( 'clikki_featured_carousel_speed_setting' ) ;
	}
	wp_localize_script( "clikki-custom-js", "clikki_carousel_speed", array('vars' => $clikki_carousel_speed) );
	
	$clikki_slider_speed = 6000;
	if ( get_theme_mod( 'clikki_slider_speed_setting' ) ) {
		$clikki_slider_speed = get_theme_mod( 'clikki_slider_speed_setting' ) ;
	}
	wp_localize_script( "clikki-custom-js", "clikki_slider_speed", array('vars' => $clikki_slider_speed) );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'clikki_scripts' );

/*****breadcrumbs*****/
function clikki_breadcrumb() {
    global $post;
    echo '<ul id="breadcrumbs">';
    if (!is_home()) {
        echo '<li><a href="';
        echo esc_url(home_url('/'));
        echo '">';
        echo 'خانه';
        echo '</a></li><li class="separator"> / </li>';
        if (is_category() || is_single()) {
            echo '<li>';
            the_category(' </li><li class="separator"> / </li><li> ');
            if (is_single()) {
                echo '</li><li class="separator"> / </li><li>';
                the_title();
                echo '</li>';
            }
        } elseif (is_page()) {
            if($post->post_parent){
                $fanzone_act = get_post_ancestors( $post->ID );
                $title = get_the_title();
                foreach ( $fanzone_act as $fanzone_inherit ) {
                    $output = '<li><a href="'.get_permalink($fanzone_inherit).'" title="'.get_the_title($fanzone_inherit).'">'.get_the_title($fanzone_inherit).'</a></li> <li class="separator">/</li>';
                }
                echo $output;
                echo '<strong title="'.$title.'"> '.$title.'</strong>';
            } else {
                echo '<li><strong> '.get_the_title().'</strong></li>';
            }
        }
    }
    echo '</ul>';
}
if(! is_user_logged_in()){
	add_filter( 'comment_form_defaults', 'clikki_remove_textarea' );
}
function clikki_remove_textarea($defaults)
{
    $defaults['comment_field'] = '';
    return $defaults;
}
add_filter( 'comment_form_default_fields', 'clikki_comment_fields', 10 );
function clikki_comment_fields( $fields ) {
 
	// get the current commenter if available
	$commenter = wp_get_current_commenter();
 
	// core functionality
	$req      = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );
	$html_req = ( $req ? " required='required'" : '' );
 
	// Change just the author field
	$fields = array(
	'comment_notes_after' => ' ',
	'comment_field' => '<p class="comment-form-comment"><textarea id="comment" name="comment" aria-required="true" placeholder="'.__( 'پیام شما...', 'clikki' ).'" rows="8" cols="37" wrap="hard"></textarea></p>',
	  
	'author' =>
		  '<div class="row"><div class="col-md-4"><p class="comment-form-author">' .
		  '<input id="author" placeholder="'. __('نام شما *...', 'clikki') .'" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) .
		  '" size="30"' . $aria_req . ' />' . ( $req ? '<span style="color:red" class="required"></span>' : '' ) . '</p></div>',

	'email' =>
		  '<div class="col-md-4"><p class="comment-form-email">' .
		  '<input id="email" placeholder="'. __('ایمیل شما *...', 'clikki') .'" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) .
		  '" size="30"' . $aria_req . ' />' . ( $req ? '<span style="color:red" class="required"></span>' : '' ) . '</p></div>',

	'url' =>
		  '<div class="col-md-4"><p class="comment-form-url">' .
		  '<input id="url" placeholder="'. __('وب سایت شما...', 'clikki') .'" name="url" type="text" value="' . esc_attr( $commenter['comment_author_url'] ) .
		  '" size="30" /></p></div></div>'
	  
	  
	);
	return $fields;
 
}

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';


/**
 * Implement the Custom Widget.
 */
require get_template_directory() . '/inc/widget.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
