<?php
/**
 * Clikki Theme Customizer.
 *
 * @package Clikki
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function clikki_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	
	$categories = get_categories();
	$cats = array();
	$i = 0;
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cats[$category->slug] = $category->name;
	}
	$wp_customize->add_panel( 'clikki_home_featured_panel', array(
		'priority'       => 10,
		'capability'     => 'edit_theme_options',
		'title'          => __('Home Page Features', 'clikki' ),
		'description'    => __('Section that will show on Home page', 'clikki' ),
	) );
	
	//slider
	$wp_customize->add_section( 'clikki_slider_section' , array(
		'title'       => __( 'Slider', 'clikki' ),
		'priority'    => 20,
		'description' => __( 'Slider Option', 'clikki' ),
		'panel'  => 'clikki_home_featured_panel',
	) );

	$wp_customize->add_setting('clikki_display_slider_setting', array(
		'default'        => 1,
		'sanitize_callback' => 'clikki_sanitize_checkbox',
	));

	$wp_customize->add_control('clikki_display_slider_control', array(
		'settings' => 'clikki_display_slider_setting',
		'label'    => __('Display Slider', 'clikki'),
		'section'  => 'clikki_slider_section',
		'type'     => 'checkbox',
		'priority'	=> 24
	));
	//  =============================
	//  Select Box               
	//  =============================
	$wp_customize->add_setting('clikki_category_setting', array(
		'default' => '',
		'sanitize_callback' => 'clikki_sanitize_category',
	));

	$wp_customize->add_control('clikki_category_control', array(
		'settings' => 'clikki_category_setting',
		'type' => 'select',
		'label' => __('Select Category:','clikki'),
		'section' => 'clikki_slider_section',
		'active_callback' =>'clikki_slider_active_callback',
		'choices' => $cats,
		'priority'	=> 25
	));
		
	//  Set Speed
	$wp_customize->add_setting( 'clikki_slider_speed_setting', array (
		'default' => '6000',
		'sanitize_callback' => 'clikki_sanitize_integer',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_slider_speed', array(
		'label'    => __( 'Slider Speed (milliseconds)', 'clikki' ),
		'section'  => 'clikki_slider_section',
		'settings' => 'clikki_slider_speed_setting',
		'active_callback' =>'clikki_slider_active_callback',
		'priority'	=> 26
	) ) );
	
	
		
	//Featured Carousel
	$wp_customize->add_section( 'clikki_featured_carousel_section' , array(
		'title'       => __( 'Carousel', 'clikki' ),
		'priority'    => 21,
		'description' => __( 'Carousel Option', 'clikki' ),
		'panel'  => 'clikki_home_featured_panel',
	) );

	$wp_customize->add_setting('clikki_display_featured_carousel_setting', array(
		'default'        => 1,
		'sanitize_callback' => 'clikki_sanitize_checkbox',
	));

	$wp_customize->add_control('clikki_display_featured_carousel_control', array(
		'settings' => 'clikki_display_featured_carousel_setting',
		'label'    => __('Display Featured Article', 'clikki'),
		'section'  => 'clikki_featured_carousel_section',
		'type'     => 'checkbox',
		'priority'	=> 27
	));
	
	//  =============================
	//  Select Box               
	//  =============================
	$wp_customize->add_setting('clikki_featured_carousel_setting', array(
		'default' => '',
		'sanitize_callback' => 'clikki_sanitize_category',
	));

	$wp_customize->add_control('clikki_featured_carousel_control', array(
		'settings' => 'clikki_featured_carousel_setting',
		'type' => 'select',
		'label' => __('Select Category:','clikki'),
		'section' => 'clikki_featured_carousel_section',
		'choices' => $cats,
		'active_callback' =>'clikki_carousel_active_callback',
		'priority'	=> 28
	));
	
	//  Set Speed
	$wp_customize->add_setting( 'clikki_featured_carousel_speed_setting', array (
		'default' => '6000',
		'sanitize_callback' => 'clikki_sanitize_integer',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_featured_carousel_speed', array(
		'label'    => __( 'Carousel Speed (milliseconds)', 'clikki' ),
		'section'  => 'clikki_featured_carousel_section',
		'settings' => 'clikki_featured_carousel_speed_setting',
		'active_callback' =>'clikki_carousel_active_callback',
		'priority'	=> 29
	) ) );
	//Carousel Label
	$wp_customize->add_setting( 'clikki_carousel_label', array (
		'default' => '',
		'sanitize_callback' => 'clikki_sanitize_text_field'
	));
	
	$wp_customize->add_control(new WP_Customize_Control($wp_customize, 'clikki_carousel_label', array(
	   'label'      => __( 'Enter Desired Label', 'clikki' ),
	   'section'    => 'clikki_featured_carousel_section',
	   'settings'   => 'clikki_carousel_label',
	   'active_callback' =>'clikki_carousel_active_callback',
	   'priority'    => 30
	   )
	));
		
	//Featured Articles
	$wp_customize->add_section( 'clikki_featured_articles_section' , array(
		'title'       => __( 'Featured Thumbnails', 'clikki' ),
		'priority'    => 22,
		'description' => __( 'Featured Article Option', 'clikki' ),
		'panel'  => 'clikki_home_featured_panel',
	) );

	$wp_customize->add_setting('clikki_display_featured_articles_setting', array(
		'default'        => 1,
		'sanitize_callback' => 'clikki_sanitize_checkbox',
	));

	$wp_customize->add_control('clikki_display_featured_articles_control', array(
		'settings' => 'clikki_display_featured_articles_setting',
		'label'    => __('Display Featured Article', 'clikki'),
		'section'  => 'clikki_featured_articles_section',
		'type'     => 'checkbox',
		'priority'	=> 31
	));

	//  =============================
	//  Select Box               
	//  =============================
	$wp_customize->add_setting('clikki_featured_articles_setting', array(
		'default' => '',
		'sanitize_callback' => 'clikki_sanitize_category',
	));

	$wp_customize->add_control('clikki_featured_articles_control', array(
		'settings' => 'clikki_featured_articles_setting',
		'type' => 'select',
		'label' => __('Select Category:','clikki'),
		'section' => 'clikki_featured_articles_section',
		'choices' => $cats,	
		'active_callback' =>'clikki_featured_active_callback',	
		'priority'	=> 32
	));
	//Featured Articles Label
	$wp_customize->add_setting( 'clikki_featured_article_label', array (
		'default' => '',
		'sanitize_callback' => 'clikki_sanitize_text_field'
	));
	
	$wp_customize->add_control(new WP_Customize_Control($wp_customize, 'clikki_featured_article_label', array(
	   'label'      => __( 'Enter Desired Label', 'clikki' ),
	   'section'    => 'clikki_featured_articles_section',
	   'settings'   => 'clikki_featured_article_label',
	   'active_callback' =>'clikki_featured_active_callback',
	   'priority'    => 33
	   )
	));
	
	$wp_customize->add_section( 'clikki_Latest_articles_section' , array(
		'title'       => __( 'Latest Posts', 'clikki' ),
		'priority'    => 23,
		'description' => __( 'Article section Option', 'clikki' ),
		'panel'  => 'clikki_home_featured_panel',
	) );
	
	
	
	//Carousel Label
	$wp_customize->add_setting( 'clikki_Latest_article_label', array (
		'default' => '',
		'sanitize_callback' => 'clikki_sanitize_text_field'
	));
	
	$wp_customize->add_control(new WP_Customize_Control($wp_customize, 'clikki_Latest_article_label', array(
	   'label'      => __( 'Enter Desired Label', 'clikki' ),
	   'section'    => 'clikki_Latest_articles_section',
	   'settings'   => 'clikki_Latest_article_label',
	   'priority'    => 34
	   )
	));
	
	/* social media option */
	$wp_customize->add_section( 'clikki_social_section' , array(
		'title'       => __( 'Social Media Icons', 'clikki' ),
		'priority'    => 25,
		'description' => __( 'Optional social media buttons in the header', 'clikki' ),
	) );

	$wp_customize->add_setting( 'clikki_facebook_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_facebook', array(
		'label'    => __( 'Enter your Facebook url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_facebook_setting',
		'priority'    => 1,
	) ) );

	$wp_customize->add_setting( 'clikki_twitter_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_twitter', array(
		'label'    => __( 'Enter your Twitter url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_twitter_setting',
		'priority'    => 2,
	) ) );
	
	$wp_customize->add_setting( 'clikki_google_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_google', array(
		'label'    => __( 'Enter your Google+ url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_google_setting',
		'priority'    => 3,
	) ) );

	$wp_customize->add_setting( 'clikki_pinterest_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_pinterest', array(
		'label'    => __( 'Enter your Pinterest url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_pinterest_setting',
		'priority'    => 4,
	) ) );

	$wp_customize->add_setting( 'clikki_linkedin_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_linkedin', array(
		'label'    => __( 'Enter your Linkedin url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_linkedin_setting',
		'priority'    => 5,
	) ) );

	$wp_customize->add_setting( 'clikki_youtube_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_youtube', array(
		'label'    => __( 'Enter your Youtube url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_youtube_setting',
		'priority'    => 6,
	) ) );

	$wp_customize->add_setting( 'clikki_tumblr_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_tumblr', array(
		'label'    => __( 'Enter your Tumblr url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_tumblr_setting',
		'priority'    => 7,
	) ) );

	$wp_customize->add_setting( 'clikki_instagram_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_instagram', array(
		'label'    => __( 'Enter your Instagram url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_instagram_setting',
		'priority'    => 8,
	) ) );

	$wp_customize->add_setting( 'clikki_flickr_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_flickr', array(
		'label'    => __( 'Enter your Flickr url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_flickr_setting',
		'priority'    => 9,
	) ) );

	$wp_customize->add_setting( 'clikki_vimeo_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_vimeo', array(
		'label'    => __( 'Enter your Vimeo url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_vimeo_setting',
		'priority'    => 1,
	) ) );
	$wp_customize->add_setting( 'clikki_rss_setting', array (
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_rss', array(
		'label'    => __( 'Enter your RSS url', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_rss_setting',
		'priority'    => 11,
	) ) );

	$wp_customize->add_setting( 'clikki_email_setting', array (			
		'sanitize_callback' => 'sanitize_email',
	) );
	
	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'clikki_email', array(
		'label'    => __( 'Enter your email address', 'clikki' ),
		'section'  => 'clikki_social_section',
		'settings' => 'clikki_email_setting',
		'priority'    => 12,
	) ) );
	
	/* color option */
	$wp_customize->add_setting( 'clikki_primary_color_setting', array (
		'default'     => '#01a0e1',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'clikki_primary_color', array(
		'label'    => __( 'Theme Primary Color', 'clikki' ),
		'section'  => 'colors',
		'settings' => 'clikki_primary_color_setting',
	) ) );
	
	$wp_customize->add_setting( 'clikki_secondary_color_setting', array (
		'default'     => '#343434',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'clikki_secondary_color', array(
		'label'    => __( 'Theme Secondary Color', 'clikki' ),
		'section'  => 'colors',
		'settings' => 'clikki_secondary_color_setting',
	) ) );
}
add_action( 'customize_register', 'clikki_customize_register' );
	
function clikki_slider_active_callback() {
	if ( get_theme_mod( 'clikki_display_slider_setting', 0 ) ) {
		return true;
	}
	return false;
}
function clikki_carousel_active_callback() {
	if ( get_theme_mod( 'clikki_display_featured_carousel_setting', 0 ) ) {
		return true;
	}
	return false;
}
function clikki_featured_active_callback() {
	if ( get_theme_mod( 'clikki_display_featured_articles_setting', 0 ) ) {
		return true;
	}
	return false;
}

/**
 * Sanitize checkbox
 */

if (!function_exists( 'clikki_sanitize_checkbox' ) ) :
	function clikki_sanitize_checkbox( $input ) {
		if ( $input != 1 ) {
			return 0;
		} else {
			return 1;
		}
	}
endif;

/**
 * Sanitize integer input
 */
if ( ! function_exists( 'clikki_sanitize_integer' ) ) :
	function clikki_sanitize_integer( $input ) {		
		return absint($input);
	}
endif;

if ( ! function_exists( 'clikki_sanitize_category' ) ){
	function clikki_sanitize_category( $input ) {
		$categories = get_categories();
		$cats = array();
		$i = 0;
		foreach($categories as $category){
			if($i==0){
				$default = $category->slug;
				$i++;
			}
			$cats[$category->slug] = $category->name;
		}
		$valid = $cats;

		if ( array_key_exists( $input, $valid ) ) {
			return $input;
		} else {
			return '';

		}
	}
}

function clikki_sanitize_text_field( $str ) {

	return esc_html(sanitize_text_field( $str ));

}
		
if ( ! function_exists( 'clikki_apply_color' ) ) :
  function clikki_apply_color() {
	?>
	<style id="color-settings">
	<?php if (esc_html(get_theme_mod('clikki_primary_color_setting')) ) { ?>
		.top-nav ul li a:hover, .social-meidia li a:hover, .site-title a:hover, .main-navigation, .footer-widget-container ul li a:hover, .clikki-recent-post .meta-info-comment a:hover, .clikki-recent-post .post-author a:hover, .widget-area ul li a:hover, a, #featured-post h3 a:hover,
.featured-articles .article-excerpt h2 a:hover, .entry-title a:hover, .site-footer a:hover, .slide-post-details h1 a:hover, .comment-meta .fn a, .reply a, #search-icon .fa-search:hover{color:<?php echo esc_html(get_theme_mod('clikki_primary_color_setting')); ?>}
		.main-navigation .current_page_item > a, .main-navigation .current-menu-item > a, .main-navigation .current_page_ancestor > a, .main-navigation .current-menu-ancestor > a, .main-navigation a:hover, .widget-title span, button, input[type="button"], input[type="reset"], input[type="submit"], .footer-widget-container thead, .footer-widget .tagcloud a, .featured-post-meta, .read_more, .next.page-numbers, .prev.page-numbers{ background:<?php echo esc_html(get_theme_mod('clikki_primary_color_setting')); ?>}
	<?php } ?>
	
	<?php if (esc_html(get_theme_mod('clikki_secondary_color_setting')) ) { ?>
		.top-bar, #site-navigation, .footer-widget-container, .widget-title, .main-navigation ul ul{ background:<?php echo esc_html(get_theme_mod('clikki_secondary_color_setting')); ?>}
	<?php } ?>
	
	</style>
	<?php	  
  }
endif;
add_action( 'wp_head', 'clikki_apply_color' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function clikki_customize_preview_js() {
	wp_enqueue_script( 'clikki_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'clikki_customize_preview_js' );
